@@ -1,12 +1,13 @@
-#!/usr/bin/env python3 import re
+#!/usr/bin/env python3
 import re
+from sys import prefix
 
 
-def silabea(word, excepciones = True):
+def silabea(word, excepciones=True):
     return silabas(word, excepciones).silabas
 
 
-def tonica(word, excepciones = True):
+def tonica(word, excepciones=True):
     return silabas(word, excepciones).tonica
 
 
@@ -30,11 +31,9 @@ def tonica_s(slbs):
 
 
 class silabas:
-    vocales = ['a', 'e', 'i', 'o', 'u',
-               'á', 'é', 'í', 'ó', 'ú',
-               'ä', 'ë', 'ï', 'ö', 'ü']
+    vocales = 'aeiouáéíóúäëïöüàèìòùAEIOUÁÉÍÓÚÄËÏÓÜÀÈÌÒÙ'
 
-    def __init__(self, palabra, excepciones = True):
+    def __init__(self, palabra, excepciones=True):
         self.palabra = self.__excepciones(palabra, excepciones)
         self.excepcions = excepciones
         self.silabas = self.__silabea(self.palabra)
@@ -42,37 +41,38 @@ class silabas:
 
     def __excepciones(self, palabra, excepciones):
         if excepciones:
-            with open("excepciones.lst") as f:                                  # Quilis 185-186. No incluyo circuito.
-                lineas = f.read()                                               # que yo elicito /cir-cui-to/,
-            nombres = lineas.splitlines()                                       # hasta que indague más en el tema
-            nombres = [nombre.strip() for nombre in nombres if not nombre.startswith('#')]
-            print(nombres)
+            import importlib.resources as pkg_resources
+            lineas = pkg_resources.read_text('silabeador', 'excepciones.lst')
+            nombres = lineas.splitlines()
+            nombres = [nombre.strip()
+                       for nombre in nombres if not nombre.startswith('#')]
         else:
             nombres = []
         uir = ['uir', 'uido', 'uida', 'uid', 'uidos', 'uidas'
                'uimos',
                'uiste', 'uisteis',  'uido', 'uida', 'uid'
-               'uiré', 'uirás', 'uirá', 'uiremos', 'uiréis', 'uirán',           # Quilis (2019, 185) exceptua el futuro
-               'uiría', 'uirías', 'uiría', 'uiríamos', 'uiríais', 'uirían']     # Quilis (2019, 185) exceptua el condicional
+               'uiré', 'uirás', 'uirá', 'uiremos', 'uiréis', 'uirán',
+               'uiría', 'uirías', 'uiría', 'uiríamos', 'uiríais', 'uirían']
 
         uar = ['uar', 'uado', 'uada', 'uad', 'uás', 'uados', 'uadas'
                'uamos', 'uáis',
                'uaba', 'uabas', 'uábamos', 'uabais', 'uaban',
                'uaste', 'uó', 'uamos', 'uasteis', 'uaron',
-               'uaré', 'uarás', 'uará', 'uaremos', 'uaréis', 'uarán',           # Quilis (2019, 185) exceptua el futuro
-               'uaría', 'uarías', 'uaría', 'uaríamos', 'uaríais', 'uarían']     # Quilis (2019, 185) exceptua el condicional
-        excepto = ['g','c']
+               'uaré', 'uarás', 'uará', 'uaremos', 'uaréis', 'uarán',
+               'uaría', 'uarías', 'uaría', 'uaríamos', 'uaríais', 'uarían']
+        acui = 'acuí'
+        excepto = ['g', 'c']
         uoso = ['uoso', 'uosa', 'uosos', 'uosas']
         if (any(x in palabra for x in nombres) or
-            any(palabra.endswith(x)  for x in nombres) or
+            any(palabra.endswith(x) for x in nombres) or
             any(palabra.endswith(x) for x in uir if len(x)+2 <= len(palabra))
             or any(palabra.endswith(x) for x in uar
                    if not palabra.endswith(f'g{x}'))):
-            palabra = re.sub('u([aeioáéó])', r'u \1', palabra)
             palabra = re.sub('i([aeouáéó])', r'i \1', palabra)
+            if not any(x in palabra for x in ['gu', 'qu', 'cu']):
+                palabra = re.sub('u([aeioáéó])', r'u \1', palabra)
         return palabra
 
-
     def __silabea(self, letras):
         extranjeras = {'à': 'a', 'è': 'e', 'ì': 'i', 'ò': 'o', 'ù': 'u',
                        'ã': 'a', 'ẽ': 'e', 'ĩ': 'i', 'õ': 'o', 'ũ': 'u',
@@ -92,37 +92,42 @@ class silabas:
         slbs[:0] = palabra
         slbs = self.__une(slbs)
         slbs = self.__separa(slbs)
-        return slbs
+        return [x.strip() for x in slbs]
 
     def __une(self, letras):
-        cerradas = ['i', 'u']
-        debiles = ['e', 'i', 'é', 'í']
-        hiatos = ['ú', 'í']
-        dieresis = ['ä', 'ë', 'ï', 'ö', 'ü']
+        cerradas = 'iuIU'
+        debiles = 'eiéí'
+        hiatos = 'úíÚÍ'
+        dieresis = 'äëïöüÄËÏÖÜ'
         lista = []
         for letra in letras:
             if len(lista) == 0:
                 lista = [letra]
-            elif (all(vocal.lower() in self.vocales
-                     for vocal in [letra, lista[-1][-1]]) and
-                  any(vocal.lower() in cerradas
-                      for vocal in [letra, lista[-1][-1]]) and not (
-                          any(y.lower() in hiatos
-                              for y in (lista[-1][-1], letra)) or
-                          any(y.lower() in dieresis
-                              for y in (lista[-1][-1], letra)) or
-                          (letra in debiles and
-                           ''.join(lista).lower().endswith('gü')) or
-                          ''.join(lista).lower().endswith('qu'))):
+            elif all(vocal in self.vocales
+                     for vocal in [letra, ultima]):
+                if letra in debiles and any(''.join(lista).lower().endswith(x)
+                                            for x in ['gü', 'qu', 'gu']):
                     lista[-1] = lista[-1] + letra
+                elif any(vocal in cerradas for vocal in letra + ultima):
+                    print(lista, letra)
+                    if letra not in hiatos+dieresis and ultima not in dieresis:
+                        lista[-1] = lista[-1] + letra
+                    elif letra == 'í' and len(lista) > 1 and (
+                        lista[-2:] == ['c','u']):
+                        lista[-1] = lista[-1] + letra
+                    else:
+                        lista = lista + [letra]
+                else:
+                    lista = lista + [letra]
             else:
                 lista = lista + [letra]
+            ultima = lista[-1][-1]
         return lista
 
     def __separa(self, letras):
         inseparables_onset = ['pl', 'bl', 'fl', 'cl', 'kl', 'gl', 'll',
                               'pr', 'br', 'fr', 'cr', 'kr', 'gr', 'rr',
-                              'tr', 'ch']
+                              'dr', 'tr', 'ch', 'dh', 'rh']
         inseparables_coda = ['ns', 'bs']
         lista = []
         onset = ''
@@ -152,8 +157,16 @@ class silabas:
                     lista = lista + [onset[2:] + letra]
                     onset = ''
                 else:
-                    lista[-1] = lista[-1] + onset[:media]
-                    lista = lista + [onset[media:] + letra]
+                    if (onset[-1] in 'dfkt' and onset[-2] in 'bcdfgjkm' +
+                        'ñpqstvwxz'
+                        or onset[-1] in 'g' and onset[-2] in 'ctjk'
+                        or onset[-1] in 'lm' and onset[-2] in 'ml'
+                            or onset[-1] == 'c' and onset[-2] == 'c'):
+                        lista[-1] = lista[-1] + onset[:-1]
+                        lista = lista + [onset[-1] + letra]
+                    else:
+                        lista[-1] = lista[-1] + onset[:media]
+                        lista = lista + [onset[media:] + letra]
                     onset = ''
             lista[-1] = lista[-1] + onset
         return lista
